@@ -7,11 +7,18 @@ from pytz import timezone
 import pytz
 
 # Use the application default credentials
+# cred = credentials.ApplicationDefault()
+# firebase_admin.initialize_app(cred, {
+#     'projectId': os.environ.get("GCP_PROJECT_ID"),
+# })
+# firebase_admin.initialize_app(cred, {
+#     'projectId': "data8x-scratch",
+# })
 cred = credentials.ApplicationDefault()
 firebase_admin.initialize_app(cred, {
-    'projectId': os.environ.get("GCP_PROJECT_ID"),
+    'projectId': "data8x-scratch",
+    'storageBucket': 'data8x-scratch.appspot.com/submissions'
 })
-
 db = firestore.client()
 date_format = "%Y-%m-%d %H:%M:%S %Z"
 date = datetime.now(tz=pytz.utc)
